@@ -9,7 +9,7 @@ app.help = '''自动撤回包含屏蔽词的消息'''
 def get_words():
     data = app.plugin_storage(
         "words", suffix=".txt",
-        default="芝士雪豹\n1!5!\n"
+        default="芝士雪豹\n雪豹闭嘴\n"
     ).load()
     words = []
     if data:
@@ -34,12 +34,22 @@ words = get_words()
 config = get_config()
 
 
+def check(msg: str):
+    for word in words:
+        if word in msg:
+            return True
+
+    if config["powerful"] == 1:
+        msg = re.sub(r'[\W]', '', msg)
+
+    for word in words:
+        if word in msg:
+            return True
+
+
 @app.on_text()
 async def _():
     msg = app.event.get_plaintext()
-    if config["powerful"] == 1:
-        msg = re.sub(r'[\W]', '', msg)
-    for word in words:
-        if word in msg:
-            await sleep(config["delay"])
-            await app.bot.delete_msg(message_id=app.event.message_id)
+    if check(msg):
+        await sleep(config["delay"])
+        await app.bot.delete_msg(message_id=app.event.message_id)
